pub struct RapUpdate {
pub timestamp: u64,
pub item_id: u64,
pub rap: u64,
}Expand description
A rap update for an item on the Rolimons deals page.
These are usually only used for validating that deals are within deal % on the client side of the deals page.
Fields
timestamp: u64The timestamp of the activity in unix time.
item_id: u64The unique identifier of the item being sold.
rap: u64The updated rap of an item.